# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/bots/bot/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/bots/bot/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Bots\\Bot\\": "packages/bots/bot/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Bots\Bot\Providers\BotServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Bot'  => Bots\Bot\Facades\Bot::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Bots\\BotTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Bots\Bot\Providers\BotServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Bots\Bot\Providers\BotServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Bots\Bot\Providers\BotServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/bot/{modulename}

**User**

    http://path-to-route-folder/user/bot/{modulename}

**Public**

    http://path-to-route-folder/bots


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/bot/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/bot/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/bot/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/bot/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/bot/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/bot/{modulename}/{slug}
    METHOD: GET